//
//  Helper.m
//  yoUni
//
//  Created by 韦瑀 on 2019/3/25.
//  Copyright © 2019 韦瑀. All rights reserved.
//

#import "Helper.h"

@implementation Helper

static Helper *helper;
+ (instancetype)sharedInstance
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        if (!helper) {
            helper = [[Helper alloc] init];
        }
    });
    return helper;
}


/**
 创建UIButton
 */
- (UIButton *)buttonWithSuperView:(UIView *)superView andNormalTitle:(NSString *)normalTitle andNormalTextColor:(UIColor *)normalTextColor andTextFont:(UIFont *)font andNormalImage:(UIImage *)normalImage backgroundColor:(UIColor *)backgroundColor addTarget:(id)target action:(SEL)action forControlEvents:(UIControlEvents)controlEvents andMasonryBlock:(MasonryBlock)masonryBlock
{
    UIButton *button = [UIButton buttonWithType:UIButtonTypeCustom];
    
    if (normalTitle) {
        [button setTitle:normalTitle forState:UIControlStateNormal];
    }
    
    if (normalTextColor) {
        [button setTitleColor:normalTextColor forState:UIControlStateNormal];
    }
    
    if (font) {
        [button.titleLabel setFont:font];
    }
    
    if (normalImage) {
        [button setImage:normalImage forState:UIControlStateNormal];
    }
    
    [button setBackgroundColor:backgroundColor];
    
    [button addTarget:target action:action forControlEvents:controlEvents];
    
    if (superView) {
        [superView addSubview:button];
        
        if (masonryBlock) {
            [button mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    return button;
}

/**
 创建UILabel
 */
- (UILabel *)labelWithSuperView:(UIView *)superView backgroundColor:(UIColor *)backgroundColor text:(NSString *)text textAlignment:(NSTextAlignment)textAlignment textColor:(UIColor *)textColor font:(UIFont *)font numberOfLines:(NSInteger)numberOfLines andMasonryBlock:(MasonryBlock)masonryBlock
{
    UILabel *label = [UILabel new];
    label.numberOfLines = numberOfLines;
    label.textColor = textColor;
    label.textAlignment = textAlignment;
    label.text = text;
    
    if (superView) {
        [superView addSubview:label];
        if (masonryBlock) {
            [label mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    if (backgroundColor) {
        label.backgroundColor = backgroundColor;
    }
    
    if (font) {
        label.font = font;
    }
    
    return label;
}

/**
 创建UITextField
 */
- (UITextField *)textFieldWithSuperView:(UIView *)superView textAlignment:(NSTextAlignment)textAlignment fontSize:(CGFloat)fontSize textColor:(UIColor *)textColor backgroundColor:(UIColor *)backgroundColor placeholder:(NSString *)placeholder placeholderColor:(UIColor *)placeholderColor placeholderFont:(CGFloat)placeholderFont andMasonryBlock:(MasonryBlock)masonryBlock
{
    UITextField *textField = [UITextField new];
    textField.textAlignment = textAlignment;
    textField.font = [UIFont systemFontOfSize:fontSize];
    
    textField.attributedPlaceholder = [[NSAttributedString alloc] initWithString:placeholder attributes:@{NSFontAttributeName:[UIFont systemFontOfSize:placeholderFont],NSForegroundColorAttributeName:placeholderColor}];
    
    textField.autocorrectionType = UITextAutocorrectionTypeNo;//不开启自动更正功能
    textField.autocapitalizationType = UITextAutocapitalizationTypeNone;//首字母不大写
    textField.tintColor = THEME_COLOR;//光标颜色
    
    if (superView) {
        [superView addSubview:textField];
        
        if (masonryBlock) {
            [textField mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    if (textColor) {
        textField.textColor = textColor;
    }
    
    if (backgroundColor) {
        textField.backgroundColor = backgroundColor;
    }
    
    return textField;
}

/**
 创建UITextView
 */
- (UITextView *)textViewWithSuperView:(UIView *)superView textAlignment:(NSTextAlignment)textAlignment fontSize:(CGFloat)fontSize textColor:(UIColor *)textColor backgroundColor:(UIColor *)backgroundColor andMasonryBlock:(MasonryBlock)masonryBlock
{
    UITextView *textView = [[UITextView alloc] init];
    textView.textAlignment = textAlignment;
    textView.font = [UIFont systemFontOfSize:fontSize];
    textView.autocorrectionType = UITextAutocorrectionTypeNo;//不开启自动更正功能
    textView.autocapitalizationType = UITextAutocapitalizationTypeNone;//首字母不大写
    textView.tintColor = THEME_COLOR;//光标颜色
    
    if (superView) {
        [superView addSubview:textView];
        
        if (masonryBlock) {
            [textView mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    if (textColor) {
        textView.textColor = textColor;
    }
    
    if (backgroundColor) {
        textView.backgroundColor = backgroundColor;
    }
    
    return textView;
}

/**
 创建UIView
 */
- (UIView *)viewWithSuperView:(UIView *)superView backgroundColor:(UIColor *)backgroundColor andMasonryBlock:(MasonryBlock)masonryBlock
{
    UIView *view = [[UIView alloc] init];
    
    if (superView) {
        [superView addSubview:view];
        
        if (masonryBlock) {
            [view mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    if (backgroundColor) {
        view.backgroundColor = backgroundColor;
    }
    
    return view;
}

/**
 创建UIImageView
 */
- (UIImageView *)imageViewWithSuperView:(UIView *)superView backgroundColor:(UIColor *)backgroundColor image:(UIImage *)image andMasonryBlock:(MasonryBlock)masonryBlock
{
    UIImageView *imageView = [[UIImageView alloc] init];
    
    if (superView) {
        [superView addSubview:imageView];
        
        if (masonryBlock) {
            [imageView mas_makeConstraints:^(MASConstraintMaker *make) {
                masonryBlock(make);
            }];
        }
    }
    
    if (backgroundColor) {
        imageView.backgroundColor = backgroundColor;
    }
    
    if (image) {
        imageView.image = image;
    }
    
    return imageView;
}


- (void)dispatchTime:(NSTimeInterval)time inMainQueueAfter:(void (^)(void))block
{
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(time * NSEC_PER_SEC)), dispatch_get_main_queue(), block);
}
    
@end
